@@ -74,7 +74,7 @@ class TestObject(object):
         if not spark:
             raise ValueError("spark utility cannot be None...")
 
-        rowCount = spark.count_table_or_view(self.__database, self.__database)
+        rowCount = spark.count_table_or_view(self.__database, self.__name)
 
         if before:
             self.__rowCountBefore = rowCount
